**Official API for risticks.xyz**

Example Code:
```py
import risticks

acc = risticks.Account(749202624171081779)

likes = acc.likes
dislikes = acc.dislikes
username = acc.username

print(f"{username}: {likes} likes, {dislikes} dislikes")```